#! /usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2012 name <email>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.

from gi.repository import GLib, GObject, Gio
from gi.repository import Unity, UnityExtras
import gettext
import feedparser
import urllib

APP_NAME = 'unity-scope-openclipart'
LOCAL_PATH = '/usr/share/locale/'
gettext.bindtextdomain(APP_NAME, LOCAL_PATH)
gettext.textdomain(APP_NAME)
_ = gettext.gettext

BUS_NAME = 'com.canonical.Unity.Scope.Graphics.Openclipart'
BUS_PATH = '/com/canonical/unity/scope/graphics/openclipart'

SVG_DIR = '/usr/share/icons/unity-icon-theme/places/svg/'
CAT_0_ICON = Gio.ThemedIcon.new(SVG_DIR + 'group-graphics.svg')
CAT_0_TITLE = _('Categorytitle')

NO_RESULTS_HINT = _('Sorry, there are no OpenClipArt results that match your search.')
SEARCH_HINT = _('Search OpenClipArt')
SEARCH_URI = 'https://openclipart.org/'


class Daemon:
    def __init__ (self):
        self.scope = Unity.Scope.new (BUS_PATH, 'openclipart')
        self.scope.props.search_hint = SEARCH_HINT
        self.scope.search_in_global = True
        cats = []
        cats.append(Unity.Category.new(CAT_0_TITLE.lower(),
                                       CAT_0_TITLE,
                                       CAT_0_ICON,
                                       Unity.CategoryRenderer.VERTICAL_TILE))
        self.scope.props.categories = cats
        self.preferences = Unity.PreferencesManager.get_default()
        self.preferences.connect('notify::remote-content-search', self._on_preference_changed)
        self.scope.connect('search-changed', self.on_search_changed)
        self.scope.props.optional_metadata_schema = {'author': 's',
                                                     'published': 's'}
        self.scope.export()

    def _on_preference_changed(self, *_):
        self.scope.queue_search_changed(Unity.SearchType.DEFAULT)

    def on_search_changed(self, scope, search, search_type, c):
        model = search.props.results_model
        model.clear()
        if self.preferences.props.remote_content_search != Unity.PreferencesManagerRemoteContent.ALL:
            search.finished()
            return
        search_string = search.props.search_string.strip()
        print ('Search changed to \'%s\'' % search_string)
        self.update_results_model(search_string, model, c)
        search.set_reply_hint('no-results-hint',
                              GLib.Variant.new_string(NO_RESULTS_HINT))
        search.finished()

    def update_results_model(self, search, model, cancellable):
        if not search:
            return
        for i in self.openclipart(search):
            if cancellable.is_cancelled():
                return
            title = i[0]
            comment = i[1]
            uri = i[2]
            icon_hint = i[3]
            published = i[4]
            author = i[5]
            model.append(uri=uri,
                         icon_hint=icon_hint,
                         category=0,
                         mimetype="text/html",
                         title=title,
                         comment=comment,
                         dnd_uri=uri,
                         result_type=Unity.ResultType.DEFAULT,
                         author=author,
                         published=published)

    def openclipart(self, search):
        results = []
        q = urllib.quote(search)
        url = "%sapi/search/?query=%s" % (SEARCH_URI, q)
        print url
        try:
            feed = feedparser.parse(url)
        except Exception as error:
            print error
            return results
        for entry in feed['entries']:
            icon, title, date, summary, uri, owner = None, '', '', '', None, ''
            try:
                if entry is None:
                    continue
                title = entry['title']
                icon = entry['media_thumbnail'][0]['url'].replace('http://', 'https://')
                uri = entry['link'].replace('http://', 'https://')
                date = entry['published']
                owner = entry['author']
                summary = entry['summary']
                if not uri or not icon:
                    continue
                results.append([title, summary, uri, icon, date, owner])
            except:
                print "Parsing error: not a valid result"
        return results


if __name__ == '__main__':
    daemon = UnityExtras.dbus_own_name (BUS_NAME, Daemon, None)
    if daemon:
        GLib.unix_signal_add(0, 2, lambda x: daemon.quit(), None)
        daemon.run([])
