# -*- coding: utf-8 -*-

from gi.repository import Dee, Gio
from unittest import TestCase, main
from src import unity_openclipart_daemon as scope

d = scope.Daemon()
searches = ['water']
mock_data = {'should_pass': 'file:tests/data/mock_openclipart_pass#',
             'should_fail': 'file:tests/data/mock_openclipart_fail#'}

class TestOpenclipart(TestCase):

    def test_search(self):
        scope.SEARCH_URI = mock_data['should_pass']
        model = Dee.SequenceModel.new()
        model.set_schema('s', 's', 'u', 'u', 's', 's', 's', 's', 's', 's')
        model.set_column_names('uri', 'icon_hint', 'category', 'result_type',
                               'mimetype', 'title', 'comment', 'dnd_uri',
                               'published', 'author')
        c = Gio.Cancellable()
        scope.Daemon.update_results_model(d, searches[0], model, c)
        self.assertEqual(model[0][0],
                         'https://openclipart.org/detail/237/water-drop-by-tomas_arad')
        self.assertEqual(model[0][1],
                         'https://openclipart.org/image/90px/svg_to_png/237/tomas_arad_water_drop.png')
        self.assertEqual(model[0][5],
                         'water drop')
        self.assertEqual(model[0][6],
                         'drop, blue, water\nDone in Skencil.')

    def test_failing_search(self):
        scope.SEARCH_URI = mock_data['should_fail']
        model = Dee.SequenceModel.new()
        model.set_schema('s', 's', 'u', 'u', 's', 's', 's', 's', 's', 's')
        model.set_column_names('uri', 'icon_hint', 'category', 'result_type',
                               'mimetype', 'title', 'comment', 'dnd_uri',
                               'published', 'author')
        c = Gio.Cancellable()
        scope.Daemon.update_results_model(d, searches[0], model, c)
        self.assertEqual(len(model), 0)

if __name__ == '__main__':
    main()
